import sys
from typing import Callable, Any, TypeVar, NamedTuple
from math import floor
from itertools import count

import smithy_dafny_standard_library.internaldafny.generated.module_ as module_
import _dafny as _dafny
import System_ as System_
import smithy_dafny_standard_library.internaldafny.generated.Wrappers as Wrappers
import smithy_dafny_standard_library.internaldafny.generated.Relations as Relations
import smithy_dafny_standard_library.internaldafny.generated.Seq_MergeSort as Seq_MergeSort
import smithy_dafny_standard_library.internaldafny.generated.Math as Math
import smithy_dafny_standard_library.internaldafny.generated.Seq as Seq
import smithy_dafny_standard_library.internaldafny.generated.BoundedInts as BoundedInts
import smithy_dafny_standard_library.internaldafny.generated.Unicode as Unicode
import smithy_dafny_standard_library.internaldafny.generated.Functions as Functions
import smithy_dafny_standard_library.internaldafny.generated.Utf8EncodingForm as Utf8EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.Utf16EncodingForm as Utf16EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.UnicodeStrings as UnicodeStrings
import smithy_dafny_standard_library.internaldafny.generated.FileIO as FileIO
import smithy_dafny_standard_library.internaldafny.generated.GeneralInternals as GeneralInternals
import smithy_dafny_standard_library.internaldafny.generated.MulInternalsNonlinear as MulInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.MulInternals as MulInternals
import smithy_dafny_standard_library.internaldafny.generated.Mul as Mul
import smithy_dafny_standard_library.internaldafny.generated.ModInternalsNonlinear as ModInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.DivInternalsNonlinear as DivInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.ModInternals as ModInternals
import smithy_dafny_standard_library.internaldafny.generated.DivInternals as DivInternals
import smithy_dafny_standard_library.internaldafny.generated.DivMod as DivMod
import smithy_dafny_standard_library.internaldafny.generated.Power as Power
import smithy_dafny_standard_library.internaldafny.generated.Logarithm as Logarithm
import smithy_dafny_standard_library.internaldafny.generated.StandardLibraryInterop as StandardLibraryInterop
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_UInt as StandardLibrary_UInt
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_MemoryMath as StandardLibrary_MemoryMath
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_Sequence as StandardLibrary_Sequence
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_String as StandardLibrary_String
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary as StandardLibrary
import smithy_dafny_standard_library.internaldafny.generated.UUID as UUID
import smithy_dafny_standard_library.internaldafny.generated.UTF8 as UTF8
import smithy_dafny_standard_library.internaldafny.generated.OsLang as OsLang

# Module: Time

class default__:
    def  __init__(self):
        pass

    @staticmethod
    def FormatMilli(diff):
        d_0_whole_ = StandardLibrary_String.default__.Base10Int2String(_dafny.euclidian_division(diff, 1000))
        d_1_frac_ = StandardLibrary_String.default__.Base10Int2String(_dafny.euclidian_modulus(diff, 1000))
        if (len(d_1_frac_)) == (1):
            return ((d_0_whole_) + (_dafny.Seq(".00"))) + (d_1_frac_)
        elif (len(d_1_frac_)) == (2):
            return ((d_0_whole_) + (_dafny.Seq(".0"))) + (d_1_frac_)
        elif True:
            return ((d_0_whole_) + (_dafny.Seq("."))) + (d_1_frac_)

    @staticmethod
    def FormatMilliDiff(start, end):
        if (start) <= (end):
            return default__.FormatMilli((end) - (start))
        elif True:
            return (_dafny.Seq("-")) + (default__.FormatMilli((start) - (end)))

    @staticmethod
    def GetAbsoluteTime():
        output: AbsoluteTime = AbsoluteTime.default()()
        d_0_ClockTime_: int
        out0_: int
        out0_ = default__.CurrentRelativeTimeMilli()
        d_0_ClockTime_ = out0_
        d_1_CpuTime_: int
        out1_: int
        out1_ = default__.GetProcessCpuTimeMillis()
        d_1_CpuTime_ = out1_
        output = AbsoluteTime_AbsoluteTime(d_0_ClockTime_, d_1_CpuTime_)
        return output
        return output

    @staticmethod
    def PrintTimeSince(start):
        d_0_t_: RelativeTime
        out0_: RelativeTime
        out0_ = default__.TimeSince(start)
        d_0_t_ = out0_
        default__.PrintTime(d_0_t_)

    @staticmethod
    def PrintTimeSinceShort(start):
        d_0_t_: RelativeTime
        out0_: RelativeTime
        out0_ = default__.TimeSince(start)
        d_0_t_ = out0_
        default__.PrintTimeShort(d_0_t_)

    @staticmethod
    def PrintTimeSinceShortChained(start):
        x: AbsoluteTime = AbsoluteTime.default()()
        d_0_end_: AbsoluteTime
        out0_: AbsoluteTime
        out0_ = default__.GetAbsoluteTime()
        d_0_end_ = out0_
        default__.PrintTimeShort(default__.TimeDiff(start, d_0_end_))
        x = d_0_end_
        return x
        return x

    @staticmethod
    def TimeDiff(start, end):
        if (((start).ClockTime) <= ((end).ClockTime)) and (((start).CpuTime) <= ((end).CpuTime)):
            return RelativeTime_RelativeTime(((end).ClockTime) - ((start).ClockTime), ((end).CpuTime) - ((start).CpuTime))
        elif True:
            return RelativeTime_RelativeTime(0, 0)

    @staticmethod
    def TimeSince(start):
        output: RelativeTime = RelativeTime.default()()
        d_0_end_: AbsoluteTime
        out0_: AbsoluteTime
        out0_ = default__.GetAbsoluteTime()
        d_0_end_ = out0_
        output = default__.TimeDiff(start, d_0_end_)
        return output

    @staticmethod
    def PrintTime(time):
        _dafny.print(_dafny.string_of(_dafny.Seq("Clock Time : ")))
        _dafny.print(_dafny.string_of(default__.FormatMilli((time).ClockTime)))
        _dafny.print(_dafny.string_of(_dafny.Seq(" CPU Time : ")))
        _dafny.print(_dafny.string_of(default__.FormatMilli((time).CpuTime)))
        _dafny.print(_dafny.string_of(_dafny.Seq("\n")))

    @staticmethod
    def PrintTimeSinceLong(start, tag, file):
        d_0_t_: RelativeTime
        out0_: RelativeTime
        out0_ = default__.TimeSince(start)
        d_0_t_ = out0_
        default__.PrintTimeLong(d_0_t_, tag, file)

    @staticmethod
    def PrintTimeLong(time, tag, file):
        d_0_val_: _dafny.Seq
        d_0_val_ = (((((((((tag) + (_dafny.Seq(" "))) + (OsLang.default__.GetOsShort())) + (_dafny.Seq(" "))) + (OsLang.default__.GetLanguageShort())) + (_dafny.Seq(" "))) + (default__.FormatMilli((time).ClockTime))) + (_dafny.Seq(" "))) + (default__.FormatMilli((time).CpuTime))) + (_dafny.Seq("\n"))
        _dafny.print(_dafny.string_of(d_0_val_))
        if (file).is_Some:
            d_1_utf8__val_: Wrappers.Result
            d_1_utf8__val_ = UTF8.default__.Encode(d_0_val_)
            if (d_1_utf8__val_).is_Success:
                d_2___v0_: Wrappers.Result
                out0_: Wrappers.Result
                out0_ = FileIO.default__.AppendBytesToFile((file).value, (d_1_utf8__val_).value)
                d_2___v0_ = out0_

    @staticmethod
    def PrintTimeShort(time):
        _dafny.print(_dafny.string_of(_dafny.Seq("CPU:")))
        _dafny.print(_dafny.string_of(default__.FormatMilli((time).CpuTime)))
        _dafny.print(_dafny.string_of(_dafny.Seq(" ")))

    @staticmethod
    def CreateGetCurrentTimeStampSuccess(value):
        return Wrappers.Result_Success(value)

    @staticmethod
    def CreateGetCurrentTimeStampFailure(error):
        return Wrappers.Result_Failure(error)


class AbsoluteTime:
    @classmethod
    def default(cls, ):
        return lambda: AbsoluteTime_AbsoluteTime(int(0), int(0))
    def __ne__(self, __o: object) -> bool:
        return not self.__eq__(__o)
    @property
    def is_AbsoluteTime(self) -> bool:
        return isinstance(self, AbsoluteTime_AbsoluteTime)

class AbsoluteTime_AbsoluteTime(AbsoluteTime, NamedTuple('AbsoluteTime', [('ClockTime', Any), ('CpuTime', Any)])):
    def __dafnystr__(self) -> str:
        return f'Time.AbsoluteTime.AbsoluteTime({_dafny.string_of(self.ClockTime)}, {_dafny.string_of(self.CpuTime)})'
    def __eq__(self, __o: object) -> bool:
        return isinstance(__o, AbsoluteTime_AbsoluteTime) and self.ClockTime == __o.ClockTime and self.CpuTime == __o.CpuTime
    def __hash__(self) -> int:
        return super().__hash__()


class RelativeTime:
    @classmethod
    def default(cls, ):
        return lambda: RelativeTime_RelativeTime(int(0), int(0))
    def __ne__(self, __o: object) -> bool:
        return not self.__eq__(__o)
    @property
    def is_RelativeTime(self) -> bool:
        return isinstance(self, RelativeTime_RelativeTime)

class RelativeTime_RelativeTime(RelativeTime, NamedTuple('RelativeTime', [('ClockTime', Any), ('CpuTime', Any)])):
    def __dafnystr__(self) -> str:
        return f'Time.RelativeTime.RelativeTime({_dafny.string_of(self.ClockTime)}, {_dafny.string_of(self.CpuTime)})'
    def __eq__(self, __o: object) -> bool:
        return isinstance(__o, RelativeTime_RelativeTime) and self.ClockTime == __o.ClockTime and self.CpuTime == __o.CpuTime
    def __hash__(self) -> int:
        return super().__hash__()




import sys
from typing import Callable, Any, TypeVar, NamedTuple
from math import floor
from itertools import count

import module_ as module_
import _dafny as _dafny
import System_ as System_
import smithy_dafny_standard_library.internaldafny.generated.Wrappers as Wrappers
import smithy_dafny_standard_library.internaldafny.generated.Relations as Relations
import smithy_dafny_standard_library.internaldafny.generated.Seq_MergeSort as Seq_MergeSort
import smithy_dafny_standard_library.internaldafny.generated.Math as Math
import smithy_dafny_standard_library.internaldafny.generated.Seq as Seq
import smithy_dafny_standard_library.internaldafny.generated.BoundedInts as BoundedInts
import smithy_dafny_standard_library.internaldafny.generated.Unicode as Unicode
import smithy_dafny_standard_library.internaldafny.generated.Functions as Functions
import smithy_dafny_standard_library.internaldafny.generated.Utf8EncodingForm as Utf8EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.Utf16EncodingForm as Utf16EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.UnicodeStrings as UnicodeStrings
import smithy_dafny_standard_library.internaldafny.generated.FileIO as FileIO
import smithy_dafny_standard_library.internaldafny.generated.GeneralInternals as GeneralInternals
import smithy_dafny_standard_library.internaldafny.generated.MulInternalsNonlinear as MulInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.MulInternals as MulInternals
import smithy_dafny_standard_library.internaldafny.generated.Mul as Mul
import smithy_dafny_standard_library.internaldafny.generated.ModInternalsNonlinear as ModInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.DivInternalsNonlinear as DivInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.ModInternals as ModInternals
import smithy_dafny_standard_library.internaldafny.generated.DivInternals as DivInternals
import smithy_dafny_standard_library.internaldafny.generated.DivMod as DivMod
import smithy_dafny_standard_library.internaldafny.generated.Power as Power
import smithy_dafny_standard_library.internaldafny.generated.Logarithm as Logarithm
import smithy_dafny_standard_library.internaldafny.generated.StandardLibraryInterop as StandardLibraryInterop
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_UInt as StandardLibrary_UInt
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_MemoryMath as StandardLibrary_MemoryMath
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_Sequence as StandardLibrary_Sequence
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_String as StandardLibrary_String
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary as StandardLibrary
import smithy_dafny_standard_library.internaldafny.generated.UUID as UUID
import smithy_dafny_standard_library.internaldafny.generated.UTF8 as UTF8
import smithy_dafny_standard_library.internaldafny.generated.OsLang as OsLang
import smithy_dafny_standard_library.internaldafny.generated.Time as Time
import smithy_dafny_standard_library.internaldafny.generated.Streams as Streams
import smithy_dafny_standard_library.internaldafny.generated.Sorting as Sorting
import smithy_dafny_standard_library.internaldafny.generated.SortedSets as SortedSets
import smithy_dafny_standard_library.internaldafny.generated.HexStrings as HexStrings
import smithy_dafny_standard_library.internaldafny.generated.GetOpt as GetOpt
import smithy_dafny_standard_library.internaldafny.generated.FloatCompare as FloatCompare
import smithy_dafny_standard_library.internaldafny.generated.ConcurrentCall as ConcurrentCall
import smithy_dafny_standard_library.internaldafny.generated.Base64 as Base64
import smithy_dafny_standard_library.internaldafny.generated.Base64Lemmas as Base64Lemmas
import smithy_dafny_standard_library.internaldafny.generated.Actions as Actions
import smithy_dafny_standard_library.internaldafny.generated.DafnyLibraries as DafnyLibraries
import TestUUID as TestUUID
import TestUTF8 as TestUTF8
import TestTime as TestTime

# Module: TestStrings

class default__:
    def  __init__(self):
        pass

    @staticmethod
    def TestHasSubStringPos():
        d_0_actual_: Wrappers.Option
        out0_: Wrappers.Option
        out0_ = StandardLibrary_String.default__.HasSubStringPos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda"), 0)
        d_0_actual_ = out0_
        if not((d_0_actual_) == (Wrappers.Option_Some(0))):
            raise _dafny.HaltException("test/TestString.dfy(19,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out1_: Wrappers.Option
        out1_ = StandardLibrary_String.default__.HasSubStringPos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda"), 1)
        d_0_actual_ = out1_
        if not((d_0_actual_) == (Wrappers.Option_None())):
            raise _dafny.HaltException("test/TestString.dfy(21,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out2_: Wrappers.Option
        out2_ = StandardLibrary_String.default__.HasSubStringPos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog"), 0)
        d_0_actual_ = out2_
        if not((d_0_actual_) == (Wrappers.Option_Some(10))):
            raise _dafny.HaltException("test/TestString.dfy(24,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out3_: Wrappers.Option
        out3_ = StandardLibrary_String.default__.HasSubStringPos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog"), 10)
        d_0_actual_ = out3_
        if not((d_0_actual_) == (Wrappers.Option_Some(10))):
            raise _dafny.HaltException("test/TestString.dfy(26,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out4_: Wrappers.Option
        out4_ = StandardLibrary_String.default__.HasSubStringPos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog"), 11)
        d_0_actual_ = out4_
        if not((d_0_actual_) == (Wrappers.Option_None())):
            raise _dafny.HaltException("test/TestString.dfy(28,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestSearchAndReplace():
        d_0_actual_: _dafny.Seq
        out0_: _dafny.Seq
        out0_ = StandardLibrary_String.default__.SearchAndReplace(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda"), _dafny.Seq("Robbie"))
        d_0_actual_ = out0_
        if not((d_0_actual_) == (_dafny.Seq("Robbie is a Dog."))):
            raise _dafny.HaltException("test/TestString.dfy(34,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out1_: _dafny.Seq
        out1_ = StandardLibrary_String.default__.SearchAndReplace(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog"), _dafny.Seq("good boy"))
        d_0_actual_ = out1_
        if not((d_0_actual_) == (_dafny.Seq("Koda is a good boy."))):
            raise _dafny.HaltException("test/TestString.dfy(36,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out2_: _dafny.Seq
        out2_ = StandardLibrary_String.default__.SearchAndReplace(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog."), _dafny.Seq("good boy!"))
        d_0_actual_ = out2_
        if not((d_0_actual_) == (_dafny.Seq("Koda is a good boy!"))):
            raise _dafny.HaltException("test/TestString.dfy(38,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out3_: _dafny.Seq
        out3_ = StandardLibrary_String.default__.SearchAndReplace(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Robbie"), _dafny.Seq("good boy!"))
        d_0_actual_ = out3_
        if not((d_0_actual_) == (_dafny.Seq("Koda is a Dog."))):
            raise _dafny.HaltException("test/TestString.dfy(40,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out4_: _dafny.Seq
        out4_ = StandardLibrary_String.default__.SearchAndReplace(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda"), _dafny.Seq("Koda"))
        d_0_actual_ = out4_
        if not((d_0_actual_) == (_dafny.Seq("Koda is a Dog."))):
            raise _dafny.HaltException("test/TestString.dfy(42,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestSearchAndReplaceAll():
        d_0_actual_: _dafny.Seq
        out0_: _dafny.Seq
        out0_ = StandardLibrary_String.default__.SearchAndReplaceAll(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda"), _dafny.Seq("Robbie"))
        d_0_actual_ = out0_
        if not((d_0_actual_) == (_dafny.Seq("Robbie is a Dog."))):
            raise _dafny.HaltException("test/TestString.dfy(48,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out1_: _dafny.Seq
        out1_ = StandardLibrary_String.default__.SearchAndReplaceAll(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog"), _dafny.Seq("good boy"))
        d_0_actual_ = out1_
        if not((d_0_actual_) == (_dafny.Seq("Koda is a good boy."))):
            raise _dafny.HaltException("test/TestString.dfy(50,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out2_: _dafny.Seq
        out2_ = StandardLibrary_String.default__.SearchAndReplaceAll(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog."), _dafny.Seq("good boy!"))
        d_0_actual_ = out2_
        if not((d_0_actual_) == (_dafny.Seq("Koda is a good boy!"))):
            raise _dafny.HaltException("test/TestString.dfy(52,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out3_: _dafny.Seq
        out3_ = StandardLibrary_String.default__.SearchAndReplaceAll(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Robbie"), _dafny.Seq("good boy!"))
        d_0_actual_ = out3_
        if not((d_0_actual_) == (_dafny.Seq("Koda is a Dog."))):
            raise _dafny.HaltException("test/TestString.dfy(54,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out4_: _dafny.Seq
        out4_ = StandardLibrary_String.default__.SearchAndReplaceAll(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda"), _dafny.Seq("Koda"))
        d_0_actual_ = out4_
        if not((d_0_actual_) == (_dafny.Seq("Koda is a Dog."))):
            raise _dafny.HaltException("test/TestString.dfy(56,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out5_: _dafny.Seq
        out5_ = StandardLibrary_String.default__.SearchAndReplaceAll(_dafny.Seq("A rose is a rose is a rose."), _dafny.Seq("rose"), _dafny.Seq("daisy"))
        d_0_actual_ = out5_
        if not((d_0_actual_) == (_dafny.Seq("A daisy is a daisy is a daisy."))):
            raise _dafny.HaltException("test/TestString.dfy(59,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out6_: _dafny.Seq
        out6_ = StandardLibrary_String.default__.SearchAndReplaceAll(_dafny.Seq("rose is a rose is a rose"), _dafny.Seq("rose"), _dafny.Seq("daisy"))
        d_0_actual_ = out6_
        if not((d_0_actual_) == (_dafny.Seq("daisy is a daisy is a daisy"))):
            raise _dafny.HaltException("test/TestString.dfy(61,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out7_: _dafny.Seq
        out7_ = StandardLibrary_String.default__.SearchAndReplaceAll(_dafny.Seq("rose is a rose is a rose"), _dafny.Seq("rose"), _dafny.Seq("rose_daisy"))
        d_0_actual_ = out7_
        if not((d_0_actual_) == (_dafny.Seq("rose_daisy is a rose_daisy is a rose_daisy"))):
            raise _dafny.HaltException("test/TestString.dfy(63,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestHasSearchAndReplacePos():
        d_0_actual_: tuple
        out0_: tuple
        out0_ = StandardLibrary_String.default__.SearchAndReplacePos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda"), _dafny.Seq("Robbie"), 0)
        d_0_actual_ = out0_
        if not((d_0_actual_) == ((_dafny.Seq("Robbie is a Dog."), Wrappers.Option_Some(6)))):
            raise _dafny.HaltException("test/TestString.dfy(69,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out1_: tuple
        out1_ = StandardLibrary_String.default__.SearchAndReplacePos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda"), _dafny.Seq("Robbie"), 1)
        d_0_actual_ = out1_
        if not((d_0_actual_) == ((_dafny.Seq("Koda is a Dog."), Wrappers.Option_None()))):
            raise _dafny.HaltException("test/TestString.dfy(71,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out2_: tuple
        out2_ = StandardLibrary_String.default__.SearchAndReplacePos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog"), _dafny.Seq("good boy"), 0)
        d_0_actual_ = out2_
        if not((d_0_actual_) == ((_dafny.Seq("Koda is a good boy."), Wrappers.Option_Some(18)))):
            raise _dafny.HaltException("test/TestString.dfy(74,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out3_: tuple
        out3_ = StandardLibrary_String.default__.SearchAndReplacePos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog"), _dafny.Seq("good boy"), 10)
        d_0_actual_ = out3_
        if not((d_0_actual_) == ((_dafny.Seq("Koda is a good boy."), Wrappers.Option_Some(18)))):
            raise _dafny.HaltException("test/TestString.dfy(76,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out4_: tuple
        out4_ = StandardLibrary_String.default__.SearchAndReplacePos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog"), _dafny.Seq("good boy"), 11)
        d_0_actual_ = out4_
        if not((d_0_actual_) == ((_dafny.Seq("Koda is a Dog."), Wrappers.Option_None()))):
            raise _dafny.HaltException("test/TestString.dfy(78,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out5_: tuple
        out5_ = StandardLibrary_String.default__.SearchAndReplacePos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog."), _dafny.Seq("good boy!"), 0)
        d_0_actual_ = out5_
        if not((d_0_actual_) == ((_dafny.Seq("Koda is a good boy!"), Wrappers.Option_Some(19)))):
            raise _dafny.HaltException("test/TestString.dfy(81,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out6_: tuple
        out6_ = StandardLibrary_String.default__.SearchAndReplacePos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog."), _dafny.Seq("good boy!"), 10)
        d_0_actual_ = out6_
        if not((d_0_actual_) == ((_dafny.Seq("Koda is a good boy!"), Wrappers.Option_Some(19)))):
            raise _dafny.HaltException("test/TestString.dfy(83,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out7_: tuple
        out7_ = StandardLibrary_String.default__.SearchAndReplacePos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog."), _dafny.Seq("good boy!"), 11)
        d_0_actual_ = out7_
        if not((d_0_actual_) == ((_dafny.Seq("Koda is a Dog."), Wrappers.Option_None()))):
            raise _dafny.HaltException("test/TestString.dfy(85,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out8_: tuple
        out8_ = StandardLibrary_String.default__.SearchAndReplacePos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Robbie"), _dafny.Seq("good boy!"), 0)
        d_0_actual_ = out8_
        if not((d_0_actual_) == ((_dafny.Seq("Koda is a Dog."), Wrappers.Option_None()))):
            raise _dafny.HaltException("test/TestString.dfy(89,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        out9_: tuple
        out9_ = StandardLibrary_String.default__.SearchAndReplacePos(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda"), _dafny.Seq("Koda"), 0)
        d_0_actual_ = out9_
        if not((d_0_actual_) == ((_dafny.Seq("Koda is a Dog."), Wrappers.Option_Some(4)))):
            raise _dafny.HaltException("test/TestString.dfy(91,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestHasSubStringPositive():
        d_0_actual_: Wrappers.Option
        out0_: Wrappers.Option
        out0_ = StandardLibrary_String.default__.HasSubString(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda"))
        d_0_actual_ = out0_
        if not((d_0_actual_) == (Wrappers.Option_Some(0))):
            raise _dafny.HaltException("test/TestString.dfy(97,4): " + _dafny.string_of(_dafny.Seq("'Koda' is in 'Koda is a Dog.' at index 0, but HasSubString does not think so")))
        out1_: Wrappers.Option
        out1_ = StandardLibrary_String.default__.HasSubString(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Koda is a Dog."))
        d_0_actual_ = out1_
        if not((d_0_actual_) == (Wrappers.Option_Some(0))):
            raise _dafny.HaltException("test/TestString.dfy(99,4): " + _dafny.string_of(_dafny.Seq("'Koda is a Dog.' is in 'Koda is a Dog.' at index 0, but HasSubString does not think so")))
        out2_: Wrappers.Option
        out2_ = StandardLibrary_String.default__.HasSubString(_dafny.Seq("Koda is a Dog."), _dafny.Seq("Dog."))
        d_0_actual_ = out2_
        if not((d_0_actual_) == (Wrappers.Option_Some(10))):
            raise _dafny.HaltException("test/TestString.dfy(101,4): " + _dafny.string_of(_dafny.Seq("'Dog.' is in 'Koda is a Dog.' at index 10, but HasSubString does not think so")))
        out3_: Wrappers.Option
        out3_ = StandardLibrary_String.default__.HasSubString(_dafny.Seq("Koda is a Dog."), _dafny.Seq("."))
        d_0_actual_ = out3_
        if not((d_0_actual_) == (Wrappers.Option_Some(13))):
            raise _dafny.HaltException("test/TestString.dfy(103,4): " + _dafny.string_of(_dafny.Seq("'.' is in 'Koda is a Dog.' at index 13, but HasSubString does not think so")))
        out4_: Wrappers.Option
        out4_ = StandardLibrary_String.default__.HasSubString(_dafny.Seq("Koda is a Dog."), _dafny.Seq(""))
        d_0_actual_ = out4_
        if not((d_0_actual_) == (Wrappers.Option_Some(0))):
            raise _dafny.HaltException("test/TestString.dfy(105,4): " + _dafny.string_of(_dafny.Seq("The empty string is in 'Koda is a Dog.' at index 0, but HasSubString does not think so")))

    @staticmethod
    def TestHasSubStringNegative():
        d_0_actual_: Wrappers.Option
        out0_: Wrappers.Option
        out0_ = StandardLibrary_String.default__.HasSubString(_dafny.Seq("Robbie is a Dog."), _dafny.Seq("Koda"))
        d_0_actual_ = out0_
        if not((d_0_actual_) == (Wrappers.Option_None())):
            raise _dafny.HaltException("test/TestString.dfy(111,4): " + _dafny.string_of(_dafny.Seq("'Robbie is a Dog.' does not contain Koda")))
        out1_: Wrappers.Option
        out1_ = StandardLibrary_String.default__.HasSubString(_dafny.Seq("\t"), _dafny.Seq(" "))
        d_0_actual_ = out1_
        if not((d_0_actual_) == (Wrappers.Option_None())):
            raise _dafny.HaltException("test/TestString.dfy(113,4): " + _dafny.string_of(_dafny.Seq("A tab is not a space")))
        out2_: Wrappers.Option
        out2_ = StandardLibrary_String.default__.HasSubString(_dafny.Seq("large"), _dafny.Seq("larger"))
        d_0_actual_ = out2_
        if not((d_0_actual_) == (Wrappers.Option_None())):
            raise _dafny.HaltException("test/TestString.dfy(115,4): " + _dafny.string_of(_dafny.Seq("Needle larger than haystack")))

    @staticmethod
    def TestFileIO():
        d_0_valueOrError0_: Wrappers.Result = Wrappers.Result.default(_dafny.defaults.tuple())()
        out0_: Wrappers.Result
        out0_ = FileIO.default__.WriteBytesToFile(_dafny.Seq("MyFile"), _dafny.Seq([1, 2, 3, 4, 5]))
        d_0_valueOrError0_ = out0_
        if not(not((d_0_valueOrError0_).IsFailure())):
            raise _dafny.HaltException("test/TestString.dfy(120,13): " + _dafny.string_of(d_0_valueOrError0_))
        d_1_x_: tuple
        d_1_x_ = (d_0_valueOrError0_).Extract()
        d_2_valueOrError1_: Wrappers.Result = Wrappers.Result.default(_dafny.defaults.tuple())()
        out1_: Wrappers.Result
        out1_ = FileIO.default__.AppendBytesToFile(_dafny.Seq("MyFile"), _dafny.Seq([6, 7, 8, 9, 10]))
        d_2_valueOrError1_ = out1_
        if not(not((d_2_valueOrError1_).IsFailure())):
            raise _dafny.HaltException("test/TestString.dfy(121,9): " + _dafny.string_of(d_2_valueOrError1_))
        d_1_x_ = (d_2_valueOrError1_).Extract()
        d_3_valueOrError2_: Wrappers.Result = Wrappers.Result.default(_dafny.defaults.tuple())()
        out2_: Wrappers.Result
        out2_ = FileIO.default__.AppendBytesToFile(_dafny.Seq("MyFile"), _dafny.Seq([11, 12, 13, 14, 15]))
        d_3_valueOrError2_ = out2_
        if not(not((d_3_valueOrError2_).IsFailure())):
            raise _dafny.HaltException("test/TestString.dfy(122,9): " + _dafny.string_of(d_3_valueOrError2_))
        d_1_x_ = (d_3_valueOrError2_).Extract()
        d_4_valueOrError3_: Wrappers.Result = Wrappers.Result.default(_dafny.Seq)()
        out3_: Wrappers.Result
        out3_ = FileIO.default__.ReadBytesFromFile(_dafny.Seq("MyFile"))
        d_4_valueOrError3_ = out3_
        if not(not((d_4_valueOrError3_).IsFailure())):
            raise _dafny.HaltException("test/TestString.dfy(123,13): " + _dafny.string_of(d_4_valueOrError3_))
        d_5_y_: _dafny.Seq
        d_5_y_ = (d_4_valueOrError3_).Extract()
        if not((d_5_y_) == (_dafny.Seq([1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15]))):
            raise _dafny.HaltException("test/TestString.dfy(124,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        d_6_valueOrError4_: Wrappers.Result = Wrappers.Result.default(_dafny.defaults.tuple())()
        out4_: Wrappers.Result
        out4_ = FileIO.default__.WriteBytesToFile(_dafny.Seq("MyFile"), _dafny.Seq([1, 2, 3, 4, 5]))
        d_6_valueOrError4_ = out4_
        if not(not((d_6_valueOrError4_).IsFailure())):
            raise _dafny.HaltException("test/TestString.dfy(125,9): " + _dafny.string_of(d_6_valueOrError4_))
        d_1_x_ = (d_6_valueOrError4_).Extract()
        d_7_valueOrError5_: Wrappers.Result = Wrappers.Result.default(_dafny.Seq)()
        out5_: Wrappers.Result
        out5_ = FileIO.default__.ReadBytesFromFile(_dafny.Seq("MyFile"))
        d_7_valueOrError5_ = out5_
        if not(not((d_7_valueOrError5_).IsFailure())):
            raise _dafny.HaltException("test/TestString.dfy(126,9): " + _dafny.string_of(d_7_valueOrError5_))
        d_5_y_ = (d_7_valueOrError5_).Extract()
        if not((d_5_y_) == (_dafny.Seq([1, 2, 3, 4, 5]))):
            raise _dafny.HaltException("test/TestString.dfy(127,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def BadFilename():
        if ((OsLang.default__.GetOsShort()) == (_dafny.Seq("Windows"))) and ((OsLang.default__.GetLanguageShort()) == (_dafny.Seq("Dotnet"))):
            return _dafny.Seq("foo:bar:baz")
        elif True:
            return _dafny.Seq("/../../MyFile")




import sys
from typing import Callable, Any, TypeVar, NamedTuple
from math import floor
from itertools import count

import module_ as module_
import _dafny as _dafny
import System_ as System_
import smithy_dafny_standard_library.internaldafny.generated.Wrappers as Wrappers
import smithy_dafny_standard_library.internaldafny.generated.Relations as Relations
import smithy_dafny_standard_library.internaldafny.generated.Seq_MergeSort as Seq_MergeSort
import smithy_dafny_standard_library.internaldafny.generated.Math as Math
import smithy_dafny_standard_library.internaldafny.generated.Seq as Seq
import smithy_dafny_standard_library.internaldafny.generated.BoundedInts as BoundedInts
import smithy_dafny_standard_library.internaldafny.generated.Unicode as Unicode
import smithy_dafny_standard_library.internaldafny.generated.Functions as Functions
import smithy_dafny_standard_library.internaldafny.generated.Utf8EncodingForm as Utf8EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.Utf16EncodingForm as Utf16EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.UnicodeStrings as UnicodeStrings
import smithy_dafny_standard_library.internaldafny.generated.FileIO as FileIO
import smithy_dafny_standard_library.internaldafny.generated.GeneralInternals as GeneralInternals
import smithy_dafny_standard_library.internaldafny.generated.MulInternalsNonlinear as MulInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.MulInternals as MulInternals
import smithy_dafny_standard_library.internaldafny.generated.Mul as Mul
import smithy_dafny_standard_library.internaldafny.generated.ModInternalsNonlinear as ModInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.DivInternalsNonlinear as DivInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.ModInternals as ModInternals
import smithy_dafny_standard_library.internaldafny.generated.DivInternals as DivInternals
import smithy_dafny_standard_library.internaldafny.generated.DivMod as DivMod
import smithy_dafny_standard_library.internaldafny.generated.Power as Power
import smithy_dafny_standard_library.internaldafny.generated.Logarithm as Logarithm
import smithy_dafny_standard_library.internaldafny.generated.StandardLibraryInterop as StandardLibraryInterop
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_UInt as StandardLibrary_UInt
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_MemoryMath as StandardLibrary_MemoryMath
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_Sequence as StandardLibrary_Sequence
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_String as StandardLibrary_String
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary as StandardLibrary
import smithy_dafny_standard_library.internaldafny.generated.UUID as UUID
import smithy_dafny_standard_library.internaldafny.generated.UTF8 as UTF8
import smithy_dafny_standard_library.internaldafny.generated.OsLang as OsLang
import smithy_dafny_standard_library.internaldafny.generated.Time as Time
import smithy_dafny_standard_library.internaldafny.generated.Streams as Streams
import smithy_dafny_standard_library.internaldafny.generated.Sorting as Sorting
import smithy_dafny_standard_library.internaldafny.generated.SortedSets as SortedSets
import smithy_dafny_standard_library.internaldafny.generated.HexStrings as HexStrings
import smithy_dafny_standard_library.internaldafny.generated.GetOpt as GetOpt
import smithy_dafny_standard_library.internaldafny.generated.FloatCompare as FloatCompare
import smithy_dafny_standard_library.internaldafny.generated.ConcurrentCall as ConcurrentCall
import smithy_dafny_standard_library.internaldafny.generated.Base64 as Base64
import smithy_dafny_standard_library.internaldafny.generated.Base64Lemmas as Base64Lemmas
import smithy_dafny_standard_library.internaldafny.generated.Actions as Actions
import smithy_dafny_standard_library.internaldafny.generated.DafnyLibraries as DafnyLibraries
import TestUUID as TestUUID
import TestUTF8 as TestUTF8
import TestTime as TestTime
import TestStrings as TestStrings

# Module: TestComputeSetToOrderedSequenceUInt8Less

class default__:
    def  __init__(self):
        pass

    @staticmethod
    def UInt8Greater(x, y):
        return (y) < (x)

    @staticmethod
    def TestSetToOrderedSequenceEmpty():
        d_0_output_: _dafny.Seq
        out0_: _dafny.Seq
        out0_ = SortedSets.default__.SetToOrderedSequence(_dafny.Set({}), StandardLibrary_UInt.default__.UInt8Less)
        d_0_output_ = out0_
        d_1_output2_: _dafny.Seq
        d_1_output2_ = SortedSets.default__.SetToOrderedSequence2(_dafny.Set({}), StandardLibrary_UInt.default__.UInt8Less)
        d_2_expected_: _dafny.Seq
        d_2_expected_ = _dafny.Seq([])
        if not((d_0_output_) == (d_2_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(31,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        if not((d_1_output2_) == (d_2_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(32,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestSetToOrderedSequenceOneItem():
        d_0_a_: _dafny.Set
        d_0_a_ = _dafny.Set({_dafny.Seq([0])})
        d_1_output_: _dafny.Seq
        out0_: _dafny.Seq
        out0_ = SortedSets.default__.SetToOrderedSequence(d_0_a_, StandardLibrary_UInt.default__.UInt8Less)
        d_1_output_ = out0_
        d_2_output2_: _dafny.Seq
        d_2_output2_ = SortedSets.default__.SetToOrderedSequence2(d_0_a_, StandardLibrary_UInt.default__.UInt8Less)
        d_3_expected_: _dafny.Seq
        d_3_expected_ = _dafny.Seq([_dafny.Seq([0])])
        if not((d_1_output_) == (d_3_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(40,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        if not((d_2_output2_) == (d_3_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(41,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestSetToOrderedSequenceSimple():
        d_0_a_: _dafny.Set
        d_0_a_ = _dafny.Set({_dafny.Seq([0, 2]), _dafny.Seq([0, 1])})
        d_1_output_: _dafny.Seq
        out0_: _dafny.Seq
        out0_ = SortedSets.default__.SetToOrderedSequence(d_0_a_, StandardLibrary_UInt.default__.UInt8Less)
        d_1_output_ = out0_
        d_2_output2_: _dafny.Seq
        d_2_output2_ = SortedSets.default__.SetToOrderedSequence2(d_0_a_, StandardLibrary_UInt.default__.UInt8Less)
        d_3_expected_: _dafny.Seq
        d_3_expected_ = _dafny.Seq([_dafny.Seq([0, 1]), _dafny.Seq([0, 2])])
        if not((d_1_output_) == (d_3_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(49,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        if not((d_2_output2_) == (d_3_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(50,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestSetToOrderedSequencePrefix():
        d_0_a_: _dafny.Set
        d_0_a_ = _dafny.Set({_dafny.Seq([0, 1, 2]), _dafny.Seq([0, 1])})
        d_1_output_: _dafny.Seq
        out0_: _dafny.Seq
        out0_ = SortedSets.default__.SetToOrderedSequence(d_0_a_, StandardLibrary_UInt.default__.UInt8Less)
        d_1_output_ = out0_
        d_2_output2_: _dafny.Seq
        d_2_output2_ = SortedSets.default__.SetToOrderedSequence2(d_0_a_, StandardLibrary_UInt.default__.UInt8Less)
        d_3_expected_: _dafny.Seq
        d_3_expected_ = _dafny.Seq([_dafny.Seq([0, 1]), _dafny.Seq([0, 1, 2])])
        if not((d_1_output_) == (d_3_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(58,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        if not((d_2_output2_) == (d_3_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(59,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestSetToOrderedSequenceComplex():
        d_0_a_: _dafny.Set
        d_0_a_ = _dafny.Set({_dafny.Seq([0, 1, 2]), _dafny.Seq([1, 1, 2]), _dafny.Seq([0, 1])})
        d_1_output_: _dafny.Seq
        out0_: _dafny.Seq
        out0_ = SortedSets.default__.SetToOrderedSequence(d_0_a_, StandardLibrary_UInt.default__.UInt8Less)
        d_1_output_ = out0_
        d_2_output2_: _dafny.Seq
        d_2_output2_ = SortedSets.default__.SetToOrderedSequence2(d_0_a_, StandardLibrary_UInt.default__.UInt8Less)
        d_3_expected_: _dafny.Seq
        d_3_expected_ = _dafny.Seq([_dafny.Seq([0, 1]), _dafny.Seq([0, 1, 2]), _dafny.Seq([1, 1, 2])])
        if not((d_1_output_) == (d_3_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(67,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        if not((d_2_output2_) == (d_3_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(68,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestSetToOrderedSequenceComplexReverse():
        d_0_a_: _dafny.Set
        d_0_a_ = _dafny.Set({_dafny.Seq([0, 1, 2]), _dafny.Seq([1, 1, 2]), _dafny.Seq([0, 1])})
        d_1_output_: _dafny.Seq
        out0_: _dafny.Seq
        out0_ = SortedSets.default__.SetToOrderedSequence(d_0_a_, default__.UInt8Greater)
        d_1_output_ = out0_
        d_2_output2_: _dafny.Seq
        d_2_output2_ = SortedSets.default__.SetToOrderedSequence2(d_0_a_, default__.UInt8Greater)
        d_3_expected_: _dafny.Seq
        d_3_expected_ = _dafny.Seq([_dafny.Seq([1, 1, 2]), _dafny.Seq([0, 1]), _dafny.Seq([0, 1, 2])])
        if not((d_1_output_) == (d_3_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(76,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        if not((d_2_output2_) == (d_3_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(77,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestSetSequence():
        d_0_a_: _dafny.Set
        d_0_a_ = _dafny.Set({_dafny.Seq([0, 1, 2]), _dafny.Seq([1, 1, 2]), _dafny.Seq([0, 1])})
        d_1_output_: _dafny.Seq
        out0_: _dafny.Seq
        out0_ = SortedSets.default__.SetToSequence(d_0_a_)
        d_1_output_ = out0_
        if not((_dafny.MultiSet(d_1_output_)) == (_dafny.MultiSet(d_0_a_))):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(83,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @staticmethod
    def TestSetToOrderedSequenceManyItems():
        d_0_time_: Time.AbsoluteTime
        out0_: Time.AbsoluteTime
        out0_ = Time.default__.GetAbsoluteTime()
        d_0_time_ = out0_
        d_1_a_: _dafny.Set
        def iife0_():
            coll0_ = _dafny.Set()
            compr_0_: int
            for compr_0_ in _dafny.IntegerRange(0, BoundedInts.default__.TWO__TO__THE__16):
                d_2_x_: int = compr_0_
                if True:
                    if ((0) <= (d_2_x_)) and ((d_2_x_) < (65535)):
                        coll0_ = coll0_.union(_dafny.Set([StandardLibrary_UInt.default__.UInt16ToSeq(d_2_x_)]))
            return _dafny.Set(coll0_)
        d_1_a_ = iife0_()
        
        out1_: Time.AbsoluteTime
        out1_ = Time.default__.PrintTimeSinceShortChained(d_0_time_)
        d_0_time_ = out1_
        d_3_output_: _dafny.Seq
        out2_: _dafny.Seq
        out2_ = SortedSets.default__.SetToOrderedSequence(d_1_a_, StandardLibrary_UInt.default__.UInt8Less)
        d_3_output_ = out2_
        d_4_output2_: _dafny.Seq
        d_4_output2_ = SortedSets.default__.SetToOrderedSequence2(d_1_a_, StandardLibrary_UInt.default__.UInt8Less)
        d_5_expected_: _dafny.Seq
        d_5_expected_ = _dafny.Seq([StandardLibrary_UInt.default__.UInt16ToSeq(d_6_i_) for d_6_i_ in range(65535)])
        if not((d_3_output_) == (d_5_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(93,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        if not((d_4_output2_) == (d_5_expected_)):
            raise _dafny.HaltException("test/TestComputeSetToOrderedSequenceUInt8Less.dfy(94,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        Time.default__.PrintTimeSinceShort(d_0_time_)




import sys
from typing import Callable, Any, TypeVar, NamedTuple
from math import floor
from itertools import count

import module_ as module_
import _dafny as _dafny
import System_ as System_
import smithy_dafny_standard_library.internaldafny.generated.Wrappers as Wrappers
import smithy_dafny_standard_library.internaldafny.generated.BoundedInts as BoundedInts
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_UInt as StandardLibrary_UInt
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_MemoryMath as StandardLibrary_MemoryMath
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_Sequence as StandardLibrary_Sequence
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_String as StandardLibrary_String
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary as StandardLibrary
import smithy_dafny_standard_library.internaldafny.generated.UTF8 as UTF8
import aws_cryptography_internal_dynamodb.internaldafny.generated.ComAmazonawsDynamodbTypes as ComAmazonawsDynamodbTypes
import smithy_dafny_standard_library.internaldafny.generated.Relations as Relations
import smithy_dafny_standard_library.internaldafny.generated.Seq_MergeSort as Seq_MergeSort
import smithy_dafny_standard_library.internaldafny.generated.Math as Math
import smithy_dafny_standard_library.internaldafny.generated.Seq as Seq
import smithy_dafny_standard_library.internaldafny.generated.Unicode as Unicode
import smithy_dafny_standard_library.internaldafny.generated.Functions as Functions
import smithy_dafny_standard_library.internaldafny.generated.Utf8EncodingForm as Utf8EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.Utf16EncodingForm as Utf16EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.UnicodeStrings as UnicodeStrings
import smithy_dafny_standard_library.internaldafny.generated.FileIO as FileIO
import smithy_dafny_standard_library.internaldafny.generated.GeneralInternals as GeneralInternals
import smithy_dafny_standard_library.internaldafny.generated.MulInternalsNonlinear as MulInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.MulInternals as MulInternals
import smithy_dafny_standard_library.internaldafny.generated.Mul as Mul
import smithy_dafny_standard_library.internaldafny.generated.ModInternalsNonlinear as ModInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.DivInternalsNonlinear as DivInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.ModInternals as ModInternals
import smithy_dafny_standard_library.internaldafny.generated.DivInternals as DivInternals
import smithy_dafny_standard_library.internaldafny.generated.DivMod as DivMod
import smithy_dafny_standard_library.internaldafny.generated.Power as Power
import smithy_dafny_standard_library.internaldafny.generated.Logarithm as Logarithm
import smithy_dafny_standard_library.internaldafny.generated.StandardLibraryInterop as StandardLibraryInterop
import smithy_dafny_standard_library.internaldafny.generated.UUID as UUID
import smithy_dafny_standard_library.internaldafny.generated.OsLang as OsLang
import smithy_dafny_standard_library.internaldafny.generated.Time as Time
import smithy_dafny_standard_library.internaldafny.generated.Streams as Streams
import smithy_dafny_standard_library.internaldafny.generated.Sorting as Sorting
import smithy_dafny_standard_library.internaldafny.generated.SortedSets as SortedSets
import smithy_dafny_standard_library.internaldafny.generated.HexStrings as HexStrings
import smithy_dafny_standard_library.internaldafny.generated.GetOpt as GetOpt
import smithy_dafny_standard_library.internaldafny.generated.FloatCompare as FloatCompare
import smithy_dafny_standard_library.internaldafny.generated.ConcurrentCall as ConcurrentCall
import smithy_dafny_standard_library.internaldafny.generated.Base64 as Base64
import smithy_dafny_standard_library.internaldafny.generated.Base64Lemmas as Base64Lemmas
import smithy_dafny_standard_library.internaldafny.generated.Actions as Actions
import smithy_dafny_standard_library.internaldafny.generated.DafnyLibraries as DafnyLibraries
import aws_cryptography_internal_dynamodb.internaldafny.generated.Com_Amazonaws_Dynamodb as Com_Amazonaws_Dynamodb

# Module: TestComAmazonawsDynamoDB

class default__:
    def  __init__(self):
        pass

    @staticmethod
    def BasicPutGetQuery():
        d_0_valueOrError0_: Wrappers.Result = None
        out0_: Wrappers.Result
        out0_ = Com_Amazonaws_Dynamodb.default__.DynamoDBClient()
        d_0_valueOrError0_ = out0_
        if not(not((d_0_valueOrError0_).IsFailure())):
            raise _dafny.HaltException("test/TestComAmazonawsDynamodb.dfy(20,18): " + _dafny.string_of(d_0_valueOrError0_))
        d_1_client_: ComAmazonawsDynamodbTypes.IDynamoDBClient
        d_1_client_ = (d_0_valueOrError0_).Extract()
        d_2_item_: _dafny.Map
        d_2_item_ = _dafny.Map({_dafny.Seq("branch-key-id"): ComAmazonawsDynamodbTypes.AttributeValue_S(_dafny.Seq("ddb-client-test")), _dafny.Seq("type"): ComAmazonawsDynamodbTypes.AttributeValue_S(_dafny.Seq("ddb-client-test")), _dafny.Seq("status"): ComAmazonawsDynamodbTypes.AttributeValue_S(_dafny.Seq("ACTIVE"))})
        d_3_putInput_: ComAmazonawsDynamodbTypes.PutItemInput
        d_3_putInput_ = ComAmazonawsDynamodbTypes.PutItemInput_PutItemInput(default__.tableNameTest, d_2_item_, Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None())
        d_4_putRet_: Wrappers.Result
        out1_: Wrappers.Result
        out1_ = (d_1_client_).PutItem(d_3_putInput_)
        d_4_putRet_ = out1_
        if (d_4_putRet_).is_Failure:
            _dafny.print(_dafny.string_of((d_4_putRet_).error))
        if not((d_4_putRet_).is_Success):
            raise _dafny.HaltException("test/TestComAmazonawsDynamodb.dfy(47,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        d_5_Key2Get_: _dafny.Map
        d_5_Key2Get_ = _dafny.Map({_dafny.Seq("branch-key-id"): ComAmazonawsDynamodbTypes.AttributeValue_S(_dafny.Seq("ddb-client-test")), _dafny.Seq("type"): ComAmazonawsDynamodbTypes.AttributeValue_S(_dafny.Seq("ddb-client-test"))})
        d_6_getInput_: ComAmazonawsDynamodbTypes.GetItemInput
        d_6_getInput_ = ComAmazonawsDynamodbTypes.GetItemInput_GetItemInput(default__.tableNameTest, d_5_Key2Get_, Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None())
        d_7_getRet_: Wrappers.Result
        out2_: Wrappers.Result
        out2_ = (d_1_client_).GetItem(d_6_getInput_)
        d_7_getRet_ = out2_
        if (d_7_getRet_).is_Failure:
            _dafny.print(_dafny.string_of((d_7_getRet_).error))
        if not((d_7_getRet_).is_Success):
            raise _dafny.HaltException("test/TestComAmazonawsDynamodb.dfy(69,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        d_8_itemOutput_: ComAmazonawsDynamodbTypes.GetItemOutput
        d_8_itemOutput_ = (d_7_getRet_).value
        if not(((d_8_itemOutput_).Item).is_Some):
            raise _dafny.HaltException("test/TestComAmazonawsDynamodb.dfy(72,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        d_9_gotItem_: _dafny.Map
        d_9_gotItem_ = ((d_8_itemOutput_).Item).value
        if not((d_9_gotItem_) == (d_2_item_)):
            raise _dafny.HaltException("test/TestComAmazonawsDynamodb.dfy(74,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        d_10_attributeNameMap_: _dafny.Map
        d_10_attributeNameMap_ = _dafny.Map({_dafny.Seq("#status"): _dafny.Seq("status"), _dafny.Seq("#branchKeyId"): _dafny.Seq("branch-key-id")})
        d_11_attributeValueMap_: _dafny.Map
        d_11_attributeValueMap_ = _dafny.Map({_dafny.Seq(":status"): ComAmazonawsDynamodbTypes.AttributeValue_S(_dafny.Seq("ACTIVE")), _dafny.Seq(":branchKeyId"): ComAmazonawsDynamodbTypes.AttributeValue_S(_dafny.Seq("ddb-client-test"))})
        d_12_queryInput_: ComAmazonawsDynamodbTypes.QueryInput
        d_12_queryInput_ = ComAmazonawsDynamodbTypes.QueryInput_QueryInput(default__.tableNameTest, Wrappers.Option_Some(default__.secIndex), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_None(), Wrappers.Option_Some(_dafny.Seq("#status = :status and #branchKeyId = :branchKeyId")), Wrappers.Option_Some(d_10_attributeNameMap_), Wrappers.Option_Some(d_11_attributeValueMap_))
        d_13_queryRet_: Wrappers.Result
        out3_: Wrappers.Result
        out3_ = (d_1_client_).Query(d_12_queryInput_)
        d_13_queryRet_ = out3_
        if (d_13_queryRet_).is_Failure:
            _dafny.print(_dafny.string_of((d_13_queryRet_).error))
        if not((d_13_queryRet_).is_Success):
            raise _dafny.HaltException("test/TestComAmazonawsDynamodb.dfy(112,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        d_14_queryOutput_: ComAmazonawsDynamodbTypes.QueryOutput
        d_14_queryOutput_ = (d_13_queryRet_).value
        if not(((d_14_queryOutput_).Items).is_Some):
            raise _dafny.HaltException("test/TestComAmazonawsDynamodb.dfy(115,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        d_15_queryItem_: _dafny.Seq
        d_15_queryItem_ = ((d_14_queryOutput_).Items).value
        if not((len(d_15_queryItem_)) == (1)):
            raise _dafny.HaltException("test/TestComAmazonawsDynamodb.dfy(117,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))
        d_16_queriedItem_: _dafny.Map
        d_16_queriedItem_ = (d_15_queryItem_)[0]
        if not((d_2_item_) == (d_16_queriedItem_)):
            raise _dafny.HaltException("test/TestComAmazonawsDynamodb.dfy(119,4): " + _dafny.string_of(_dafny.Seq("expectation violation")))

    @_dafny.classproperty
    def tableNameTest(instance):
        return _dafny.Seq("KeyStoreTestTable")
    @_dafny.classproperty
    def secIndex(instance):
        return _dafny.Seq("Active-Keys")



import sys
from typing import Callable, Any, TypeVar, NamedTuple
from math import floor
from itertools import count

import smithy_dafny_standard_library.internaldafny.generated.module_ as module_
import _dafny as _dafny
import System_ as System_
import smithy_dafny_standard_library.internaldafny.generated.Wrappers as Wrappers
import smithy_dafny_standard_library.internaldafny.generated.Relations as Relations
import smithy_dafny_standard_library.internaldafny.generated.Seq_MergeSort as Seq_MergeSort
import smithy_dafny_standard_library.internaldafny.generated.Math as Math
import smithy_dafny_standard_library.internaldafny.generated.Seq as Seq
import smithy_dafny_standard_library.internaldafny.generated.BoundedInts as BoundedInts
import smithy_dafny_standard_library.internaldafny.generated.Unicode as Unicode
import smithy_dafny_standard_library.internaldafny.generated.Functions as Functions
import smithy_dafny_standard_library.internaldafny.generated.Utf8EncodingForm as Utf8EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.Utf16EncodingForm as Utf16EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.UnicodeStrings as UnicodeStrings
import smithy_dafny_standard_library.internaldafny.generated.FileIO as FileIO
import smithy_dafny_standard_library.internaldafny.generated.GeneralInternals as GeneralInternals
import smithy_dafny_standard_library.internaldafny.generated.MulInternalsNonlinear as MulInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.MulInternals as MulInternals
import smithy_dafny_standard_library.internaldafny.generated.Mul as Mul
import smithy_dafny_standard_library.internaldafny.generated.ModInternalsNonlinear as ModInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.DivInternalsNonlinear as DivInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.ModInternals as ModInternals
import smithy_dafny_standard_library.internaldafny.generated.DivInternals as DivInternals
import smithy_dafny_standard_library.internaldafny.generated.DivMod as DivMod
import smithy_dafny_standard_library.internaldafny.generated.Power as Power
import smithy_dafny_standard_library.internaldafny.generated.Logarithm as Logarithm
import smithy_dafny_standard_library.internaldafny.generated.StandardLibraryInterop as StandardLibraryInterop
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_UInt as StandardLibrary_UInt
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_MemoryMath as StandardLibrary_MemoryMath
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_Sequence as StandardLibrary_Sequence

# Module: StandardLibrary_String

class default__:
    def  __init__(self):
        pass

    @staticmethod
    def Int2Digits(n, base):
        d_0___accumulator_ = _dafny.Seq([])
        while True:
            with _dafny.label():
                if (n) == (0):
                    return (_dafny.Seq([])) + (d_0___accumulator_)
                elif True:
                    d_0___accumulator_ = (_dafny.Seq([_dafny.euclidian_modulus(n, base)])) + (d_0___accumulator_)
                    in0_ = _dafny.euclidian_division(n, base)
                    in1_ = base
                    n = in0_
                    base = in1_
                    raise _dafny.TailCall()
                break

    @staticmethod
    def Digits2String(digits, chars):
        d_0___accumulator_ = _dafny.Seq([])
        while True:
            with _dafny.label():
                if (digits) == (_dafny.Seq([])):
                    return (d_0___accumulator_) + (_dafny.Seq(""))
                elif True:
                    d_0___accumulator_ = (d_0___accumulator_) + (_dafny.Seq([(chars)[(digits)[0]]]))
                    in0_ = _dafny.Seq((digits)[1::])
                    in1_ = chars
                    digits = in0_
                    chars = in1_
                    raise _dafny.TailCall()
                break

    @staticmethod
    def Int2String(n, chars):
        d_0_base_ = len(chars)
        if (n) == (0):
            return _dafny.Seq("0")
        elif (n) > (0):
            return default__.Digits2String(default__.Int2Digits(n, d_0_base_), chars)
        elif True:
            return (_dafny.Seq("-")) + (default__.Digits2String(default__.Int2Digits((0) - (n), d_0_base_), chars))

    @staticmethod
    def Base10Int2String(n):
        return default__.Int2String(n, default__.Base10)

    @staticmethod
    def SearchAndReplace(source, old__str, new__str):
        o: _dafny.Seq = _dafny.Seq({})
        d_0_old__pos_: Wrappers.Option
        out0_: Wrappers.Option
        out0_ = default__.HasSubString(source, old__str)
        d_0_old__pos_ = out0_
        if (d_0_old__pos_).is_None:
            o = source
            return o
        elif True:
            d_1_pos_: int
            d_1_pos_ = (d_0_old__pos_).value
            d_2_source__len_: int
            d_2_source__len_ = len(source)
            d_3_old__str__len_: int
            d_3_old__str__len_ = len(old__str)
            o = ((_dafny.Seq((source)[:d_1_pos_:])) + (new__str)) + (_dafny.Seq((source)[(d_1_pos_) + (d_3_old__str__len_)::]))
            return o
        return o

    @staticmethod
    def SearchAndReplacePos(source, old__str, new__str, pos):
        o: tuple = (_dafny.Seq({}), Wrappers.Option.default()())
        d_0_old__pos_: Wrappers.Option
        out0_: Wrappers.Option
        out0_ = default__.HasSubStringPos(source, old__str, pos)
        d_0_old__pos_ = out0_
        if (d_0_old__pos_).is_None:
            o = (source, Wrappers.Option_None())
            return o
        elif True:
            d_1_source__len_: int
            d_1_source__len_ = len(source)
            d_2_old__str__len_: int
            d_2_old__str__len_ = len(old__str)
            d_3_new__str__len_: int
            d_3_new__str__len_ = len(new__str)
            o = (((_dafny.Seq((source)[:(d_0_old__pos_).value:])) + (new__str)) + (_dafny.Seq((source)[((d_0_old__pos_).value) + (d_2_old__str__len_)::])), Wrappers.Option_Some(StandardLibrary_MemoryMath.default__.Add((d_0_old__pos_).value, d_3_new__str__len_)))
            o = o
            return o
        return o

    @staticmethod
    def SearchAndReplaceAll(source__in, old__str, new__str):
        o: _dafny.Seq = _dafny.Seq({})
        d_0_pos_: int
        d_0_pos_ = 0
        d_1_source_: _dafny.Seq
        d_1_source_ = source__in
        while True:
            d_2_res_: tuple
            out0_: tuple
            out0_ = default__.SearchAndReplacePos(d_1_source_, old__str, new__str, d_0_pos_)
            d_2_res_ = out0_
            if ((d_2_res_)[1]).is_None:
                d_0_pos_ = len(d_1_source_)
                o = (d_2_res_)[0]
                return o
            d_1_source_ = (d_2_res_)[0]
            d_0_pos_ = ((d_2_res_)[1]).value
        return o

    @staticmethod
    def HasSubString(haystack, needle):
        o: Wrappers.Option = Wrappers.Option.default()()
        if (len(haystack)) < (len(needle)):
            o = Wrappers.Option_None()
            return o
        d_0_size_: int
        d_0_size_ = len(needle)
        d_1_limit_: int
        d_1_limit_ = StandardLibrary_MemoryMath.default__.Add((len(haystack)) - (d_0_size_), 1)
        hi0_ = d_1_limit_
        for d_2_index_ in range(0, hi0_):
            if StandardLibrary_Sequence.default__.SequenceEqual(haystack, needle, d_2_index_, 0, d_0_size_):
                o = Wrappers.Option_Some(d_2_index_)
                return o
        o = Wrappers.Option_None()
        return o
        return o

    @staticmethod
    def HasSubStringPos(haystack, needle, pos):
        o: Wrappers.Option = Wrappers.Option.default()()
        if ((len(haystack)) - (pos)) < (len(needle)):
            o = Wrappers.Option_None()
            return o
        d_0_size_: int
        d_0_size_ = len(needle)
        d_1_limit_: int
        d_1_limit_ = StandardLibrary_MemoryMath.default__.Add((len(haystack)) - (d_0_size_), 1)
        hi0_ = d_1_limit_
        for d_2_index_ in range(pos, hi0_):
            if StandardLibrary_Sequence.default__.SequenceEqual(haystack, needle, d_2_index_, 0, d_0_size_):
                o = Wrappers.Option_Some(d_2_index_)
                return o
        o = Wrappers.Option_None()
        return o
        return o

    @_dafny.classproperty
    def Base10(instance):
        return _dafny.Seq(['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'])



import sys
from typing import Callable, Any, TypeVar, NamedTuple
from math import floor
from itertools import count

import smithy_dafny_standard_library.internaldafny.generated.module_ as module_
import _dafny as _dafny
import System_ as System_
import smithy_dafny_standard_library.internaldafny.generated.Wrappers as Wrappers
import smithy_dafny_standard_library.internaldafny.generated.Relations as Relations
import smithy_dafny_standard_library.internaldafny.generated.Seq_MergeSort as Seq_MergeSort
import smithy_dafny_standard_library.internaldafny.generated.Math as Math
import smithy_dafny_standard_library.internaldafny.generated.Seq as Seq
import smithy_dafny_standard_library.internaldafny.generated.BoundedInts as BoundedInts
import smithy_dafny_standard_library.internaldafny.generated.Unicode as Unicode
import smithy_dafny_standard_library.internaldafny.generated.Functions as Functions
import smithy_dafny_standard_library.internaldafny.generated.Utf8EncodingForm as Utf8EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.Utf16EncodingForm as Utf16EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.UnicodeStrings as UnicodeStrings
import smithy_dafny_standard_library.internaldafny.generated.FileIO as FileIO
import smithy_dafny_standard_library.internaldafny.generated.GeneralInternals as GeneralInternals
import smithy_dafny_standard_library.internaldafny.generated.MulInternalsNonlinear as MulInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.MulInternals as MulInternals
import smithy_dafny_standard_library.internaldafny.generated.Mul as Mul
import smithy_dafny_standard_library.internaldafny.generated.ModInternalsNonlinear as ModInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.DivInternalsNonlinear as DivInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.ModInternals as ModInternals
import smithy_dafny_standard_library.internaldafny.generated.DivInternals as DivInternals
import smithy_dafny_standard_library.internaldafny.generated.DivMod as DivMod
import smithy_dafny_standard_library.internaldafny.generated.Power as Power
import smithy_dafny_standard_library.internaldafny.generated.Logarithm as Logarithm
import smithy_dafny_standard_library.internaldafny.generated.StandardLibraryInterop as StandardLibraryInterop
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_UInt as StandardLibrary_UInt
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_MemoryMath as StandardLibrary_MemoryMath

# Module: StandardLibrary_Sequence

class default__:
    def  __init__(self):
        pass

    @staticmethod
    def MapWithResult(f, xs, pos, acc):
        while True:
            with _dafny.label():
                if (len(xs)) == (pos):
                    return Wrappers.Result_Success(acc)
                elif True:
                    d_0_valueOrError0_ = f((xs)[pos])
                    if (d_0_valueOrError0_).IsFailure():
                        return (d_0_valueOrError0_).PropagateFailure()
                    elif True:
                        d_1_head_ = (d_0_valueOrError0_).Extract()
                        in0_ = f
                        in1_ = xs
                        in2_ = (pos) + (1)
                        in3_ = (acc) + (_dafny.Seq([d_1_head_]))
                        f = in0_
                        xs = in1_
                        pos = in2_
                        acc = in3_
                        raise _dafny.TailCall()
                break

    @staticmethod
    def Flatten(xs, pos, acc):
        while True:
            with _dafny.label():
                if (len(xs)) == (pos):
                    return acc
                elif True:
                    in0_ = xs
                    in1_ = (pos) + (1)
                    in2_ = (acc) + ((xs)[pos])
                    xs = in0_
                    pos = in1_
                    acc = in2_
                    raise _dafny.TailCall()
                break

    @staticmethod
    def SequenceEqualNat(seq1, seq2, start1, start2, size):
        return default__.SequenceEqual(seq1, seq2, start1, start2, size)

    @staticmethod
    def SequenceEqual(seq1, seq2, start1, start2, size):
        ret: bool = False
        d_0_j_: int
        d_0_j_ = start2
        hi0_ = (start1) + (size)
        for d_1_i_ in range(start1, hi0_):
            if ((seq1)[d_1_i_]) != ((seq2)[d_0_j_]):
                ret = False
                return ret
            d_0_j_ = (d_0_j_) + (1)
        ret = True
        return ret
        return ret




# Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0
# Do not modify this file. This file is machine generated, and any changes to it will be overwritten.

import aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter
from copy import deepcopy


class InternalBoto3DynamoDBFormatConverter:
    def __init__(self, item_handler, condition_handler):
        self._item_handler = item_handler
        self._condition_handler = condition_handler

    def BatchExecuteStatementInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_BatchExecuteStatementInput(
            boto3_input, item_handler, condition_handler
        )

    def BatchExecuteStatementOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_BatchExecuteStatementOutput(
            boto3_input, item_handler, condition_handler
        )

    def BatchGetItemInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_BatchGetItemInput(
            boto3_input, item_handler, condition_handler
        )

    def BatchGetItemOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_BatchGetItemOutput(
            boto3_input, item_handler, condition_handler
        )

    def BatchWriteItemInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_BatchWriteItemInput(
            boto3_input, item_handler, condition_handler
        )

    def BatchWriteItemOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_BatchWriteItemOutput(
            boto3_input, item_handler, condition_handler
        )

    def CreateBackupInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_CreateBackupInput(
            boto3_input, item_handler, condition_handler
        )

    def CreateBackupOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_CreateBackupOutput(
            boto3_input, item_handler, condition_handler
        )

    def CreateGlobalTableInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_CreateGlobalTableInput(
            boto3_input, item_handler, condition_handler
        )

    def CreateGlobalTableOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_CreateGlobalTableOutput(
            boto3_input, item_handler, condition_handler
        )

    def CreateTableInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_CreateTableInput(
            boto3_input, item_handler, condition_handler
        )

    def CreateTableOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_CreateTableOutput(
            boto3_input, item_handler, condition_handler
        )

    def DeleteBackupInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DeleteBackupInput(
            boto3_input, item_handler, condition_handler
        )

    def DeleteBackupOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DeleteBackupOutput(
            boto3_input, item_handler, condition_handler
        )

    def DeleteItemInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DeleteItemInput(
            boto3_input, item_handler, condition_handler
        )

    def DeleteItemOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DeleteItemOutput(
            boto3_input, item_handler, condition_handler
        )

    def DeleteResourcePolicyInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DeleteResourcePolicyInput(
            boto3_input, item_handler, condition_handler
        )

    def DeleteResourcePolicyOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DeleteResourcePolicyOutput(
            boto3_input, item_handler, condition_handler
        )

    def DeleteTableInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DeleteTableInput(
            boto3_input, item_handler, condition_handler
        )

    def DeleteTableOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DeleteTableOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeBackupInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeBackupInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeBackupOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeBackupOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeContinuousBackupsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeContinuousBackupsInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeContinuousBackupsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeContinuousBackupsOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeContributorInsightsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeContributorInsightsInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeContributorInsightsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeContributorInsightsOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeEndpointsRequest(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeEndpointsRequest(
            boto3_input, item_handler, condition_handler
        )

    def DescribeEndpointsResponse(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeEndpointsResponse(
            boto3_input, item_handler, condition_handler
        )

    def DescribeExportInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeExportInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeExportOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeExportOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeGlobalTableInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeGlobalTableInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeGlobalTableOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeGlobalTableOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeGlobalTableSettingsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeGlobalTableSettingsInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeGlobalTableSettingsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeGlobalTableSettingsOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeImportInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeImportInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeImportOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeImportOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeKinesisStreamingDestinationInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeKinesisStreamingDestinationInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeKinesisStreamingDestinationOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeKinesisStreamingDestinationOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeLimitsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeLimitsInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeLimitsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeLimitsOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeTableInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeTableInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeTableOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeTableOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeTableReplicaAutoScalingInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeTableReplicaAutoScalingInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeTableReplicaAutoScalingOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeTableReplicaAutoScalingOutput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeTimeToLiveInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeTimeToLiveInput(
            boto3_input, item_handler, condition_handler
        )

    def DescribeTimeToLiveOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DescribeTimeToLiveOutput(
            boto3_input, item_handler, condition_handler
        )

    def DisableKinesisStreamingDestinationInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DisableKinesisStreamingDestinationInput(
            boto3_input, item_handler, condition_handler
        )

    def DisableKinesisStreamingDestinationOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_DisableKinesisStreamingDestinationOutput(
            boto3_input, item_handler, condition_handler
        )

    def EnableKinesisStreamingDestinationInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_EnableKinesisStreamingDestinationInput(
            boto3_input, item_handler, condition_handler
        )

    def EnableKinesisStreamingDestinationOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_EnableKinesisStreamingDestinationOutput(
            boto3_input, item_handler, condition_handler
        )

    def ExecuteStatementInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ExecuteStatementInput(
            boto3_input, item_handler, condition_handler
        )

    def ExecuteStatementOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ExecuteStatementOutput(
            boto3_input, item_handler, condition_handler
        )

    def ExecuteTransactionInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ExecuteTransactionInput(
            boto3_input, item_handler, condition_handler
        )

    def ExecuteTransactionOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ExecuteTransactionOutput(
            boto3_input, item_handler, condition_handler
        )

    def ExportTableToPointInTimeInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ExportTableToPointInTimeInput(
            boto3_input, item_handler, condition_handler
        )

    def ExportTableToPointInTimeOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ExportTableToPointInTimeOutput(
            boto3_input, item_handler, condition_handler
        )

    def GetItemInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_GetItemInput(
            boto3_input, item_handler, condition_handler
        )

    def GetItemOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_GetItemOutput(
            boto3_input, item_handler, condition_handler
        )

    def GetResourcePolicyInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_GetResourcePolicyInput(
            boto3_input, item_handler, condition_handler
        )

    def GetResourcePolicyOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_GetResourcePolicyOutput(
            boto3_input, item_handler, condition_handler
        )

    def ImportTableInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ImportTableInput(
            boto3_input, item_handler, condition_handler
        )

    def ImportTableOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ImportTableOutput(
            boto3_input, item_handler, condition_handler
        )

    def ListBackupsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListBackupsInput(
            boto3_input, item_handler, condition_handler
        )

    def ListBackupsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListBackupsOutput(
            boto3_input, item_handler, condition_handler
        )

    def ListContributorInsightsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListContributorInsightsInput(
            boto3_input, item_handler, condition_handler
        )

    def ListContributorInsightsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListContributorInsightsOutput(
            boto3_input, item_handler, condition_handler
        )

    def ListExportsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListExportsInput(
            boto3_input, item_handler, condition_handler
        )

    def ListExportsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListExportsOutput(
            boto3_input, item_handler, condition_handler
        )

    def ListGlobalTablesInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListGlobalTablesInput(
            boto3_input, item_handler, condition_handler
        )

    def ListGlobalTablesOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListGlobalTablesOutput(
            boto3_input, item_handler, condition_handler
        )

    def ListImportsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListImportsInput(
            boto3_input, item_handler, condition_handler
        )

    def ListImportsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListImportsOutput(
            boto3_input, item_handler, condition_handler
        )

    def ListTablesInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListTablesInput(
            boto3_input, item_handler, condition_handler
        )

    def ListTablesOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListTablesOutput(
            boto3_input, item_handler, condition_handler
        )

    def ListTagsOfResourceInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListTagsOfResourceInput(
            boto3_input, item_handler, condition_handler
        )

    def ListTagsOfResourceOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ListTagsOfResourceOutput(
            boto3_input, item_handler, condition_handler
        )

    def PutItemInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_PutItemInput(
            boto3_input, item_handler, condition_handler
        )

    def PutItemOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_PutItemOutput(
            boto3_input, item_handler, condition_handler
        )

    def PutResourcePolicyInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_PutResourcePolicyInput(
            boto3_input, item_handler, condition_handler
        )

    def PutResourcePolicyOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_PutResourcePolicyOutput(
            boto3_input, item_handler, condition_handler
        )

    def QueryInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_QueryInput(
            boto3_input, item_handler, condition_handler
        )

    def QueryOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_QueryOutput(
            boto3_input, item_handler, condition_handler
        )

    def RestoreTableFromBackupInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_RestoreTableFromBackupInput(
            boto3_input, item_handler, condition_handler
        )

    def RestoreTableFromBackupOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_RestoreTableFromBackupOutput(
            boto3_input, item_handler, condition_handler
        )

    def RestoreTableToPointInTimeInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_RestoreTableToPointInTimeInput(
            boto3_input, item_handler, condition_handler
        )

    def RestoreTableToPointInTimeOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_RestoreTableToPointInTimeOutput(
            boto3_input, item_handler, condition_handler
        )

    def ScanInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ScanInput(
            boto3_input, item_handler, condition_handler
        )

    def ScanOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_ScanOutput(
            boto3_input, item_handler, condition_handler
        )

    def TagResourceInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_TagResourceInput(
            boto3_input, item_handler, condition_handler
        )

    def Unit(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return None

    def TransactGetItemsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_TransactGetItemsInput(
            boto3_input, item_handler, condition_handler
        )

    def TransactGetItemsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_TransactGetItemsOutput(
            boto3_input, item_handler, condition_handler
        )

    def TransactWriteItemsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_TransactWriteItemsInput(
            boto3_input, item_handler, condition_handler
        )

    def TransactWriteItemsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_TransactWriteItemsOutput(
            boto3_input, item_handler, condition_handler
        )

    def UntagResourceInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UntagResourceInput(
            boto3_input, item_handler, condition_handler
        )

    def Unit(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return None

    def UpdateContinuousBackupsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateContinuousBackupsInput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateContinuousBackupsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateContinuousBackupsOutput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateContributorInsightsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateContributorInsightsInput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateContributorInsightsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateContributorInsightsOutput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateGlobalTableInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateGlobalTableInput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateGlobalTableOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateGlobalTableOutput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateGlobalTableSettingsInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateGlobalTableSettingsInput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateGlobalTableSettingsOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateGlobalTableSettingsOutput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateItemInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateItemInput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateItemOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateItemOutput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateKinesisStreamingDestinationInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateKinesisStreamingDestinationInput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateKinesisStreamingDestinationOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateKinesisStreamingDestinationOutput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateTableInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateTableInput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateTableOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateTableOutput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateTableReplicaAutoScalingInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateTableReplicaAutoScalingInput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateTableReplicaAutoScalingOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateTableReplicaAutoScalingOutput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateTimeToLiveInput(self, boto3_input) -> dict:
        original_request = boto3_input
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateTimeToLiveInput(
            boto3_input, item_handler, condition_handler
        )

    def UpdateTimeToLiveOutput(self, boto3_input) -> dict:
        original_request = deepcopy(boto3_input)
        item_handler = self._item_handler
        condition_handler = self._condition_handler
        return aws_cryptography_internal_dynamodb.smithygenerated.com_amazonaws_dynamodb.aws_sdk_format_converter.com_amazonaws_dynamodb_UpdateTimeToLiveOutput(
            boto3_input, item_handler, condition_handler
        )



import sys
from typing import Callable, Any, TypeVar, NamedTuple
from math import floor
from itertools import count

import smithy_dafny_standard_library.internaldafny.generated.module_ as module_
import _dafny as _dafny
import System_ as System_
import smithy_dafny_standard_library.internaldafny.generated.Wrappers as Wrappers
import smithy_dafny_standard_library.internaldafny.generated.Relations as Relations
import smithy_dafny_standard_library.internaldafny.generated.Seq_MergeSort as Seq_MergeSort
import smithy_dafny_standard_library.internaldafny.generated.Math as Math
import smithy_dafny_standard_library.internaldafny.generated.Seq as Seq
import smithy_dafny_standard_library.internaldafny.generated.BoundedInts as BoundedInts
import smithy_dafny_standard_library.internaldafny.generated.Unicode as Unicode
import smithy_dafny_standard_library.internaldafny.generated.Functions as Functions
import smithy_dafny_standard_library.internaldafny.generated.Utf8EncodingForm as Utf8EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.Utf16EncodingForm as Utf16EncodingForm
import smithy_dafny_standard_library.internaldafny.generated.UnicodeStrings as UnicodeStrings
import smithy_dafny_standard_library.internaldafny.generated.FileIO as FileIO
import smithy_dafny_standard_library.internaldafny.generated.GeneralInternals as GeneralInternals
import smithy_dafny_standard_library.internaldafny.generated.MulInternalsNonlinear as MulInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.MulInternals as MulInternals
import smithy_dafny_standard_library.internaldafny.generated.Mul as Mul
import smithy_dafny_standard_library.internaldafny.generated.ModInternalsNonlinear as ModInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.DivInternalsNonlinear as DivInternalsNonlinear
import smithy_dafny_standard_library.internaldafny.generated.ModInternals as ModInternals
import smithy_dafny_standard_library.internaldafny.generated.DivInternals as DivInternals
import smithy_dafny_standard_library.internaldafny.generated.DivMod as DivMod
import smithy_dafny_standard_library.internaldafny.generated.Power as Power
import smithy_dafny_standard_library.internaldafny.generated.Logarithm as Logarithm
import smithy_dafny_standard_library.internaldafny.generated.StandardLibraryInterop as StandardLibraryInterop
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_UInt as StandardLibrary_UInt
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_MemoryMath as StandardLibrary_MemoryMath
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_Sequence as StandardLibrary_Sequence
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary_String as StandardLibrary_String
import smithy_dafny_standard_library.internaldafny.generated.StandardLibrary as StandardLibrary

# Module: UUID

class default__:
    def  __init__(self):
        pass

    @staticmethod
    def CreateBytesSuccess(bytes):
        return Wrappers.Result_Success(bytes)

    @staticmethod
    def CreateBytesFailure(error):
        return Wrappers.Result_Failure(error)

    @staticmethod
    def CreateStringSuccess(s):
        return Wrappers.Result_Success(s)

    @staticmethod
    def CreateStringFailure(error):
        return Wrappers.Result_Failure(error)

